@@ -255,6 +255,8 @@ def test_cli_train(
                 42,
                 "--model_save_dir",
                 "trained-models",
+                "--use_gpu",
+                False,
             ],
         )
 
@@ -293,6 +295,7 @@ def test_cli_train(
         "random_seed": 42,
         "model_save_dir": "trained-models",
         "n_threads": 16,  # assigned
+        "use_gpu": False,
     }
     expected_field_config_name_dict = {
         "key": "name",
@@ -351,6 +354,7 @@ def test_cli_train(
         model_save_verbose=True,
         tb_save_dir=expected_args_dict["tb_save_dir"],
         tb_name=expected_args_dict["tb_name"],
+        use_gpu=expected_args_dict["use_gpu"],
     )
     datamodule = mock_model.return_value.fit.call_args[0][0]
 
@@ -396,9 +400,9 @@ def test_cli_train(
 @mock.patch("torch.manual_seed")
 @mock.patch("numpy.random.seed")
 @mock.patch("random.seed")
-@mock.patch("torch.cuda.is_available", return_value=False)
+@mock.patch("torch.device")
 def test_cli_predict(
-    mock_cuda_is_available,
+    mock_torch_device,
     mock_random_seed,
     mock_np_random_seed,
     mock_torch_random_seed,
@@ -461,6 +465,8 @@ def test_cli_predict(
                 42,
                 "--output_json",
                 expected_output_json,
+                "--use_gpu",
+                False,
             ],
         )
 
@@ -494,7 +500,7 @@ def test_cli_predict(
     mock_torch_random_seed.assert_called_once_with(expected_args_dict["random_seed"])
 
     # cuda asserts
-    mock_cuda_is_available.assert_called_once()
+    mock_torch_device.assert_called_once_with("cpu")
 
     # predict_pairs asserts
     expected_record_dict = {record["id"]: record for record in UNLABELED_RECORD_DICT_VALUES}
